@@ -10,6 +10,7 @@ EXTENSIONS = {
     'bash': {'text', 'shell', 'bash'},
     'bat': {'text', 'batch'},
     'bats': {'text', 'shell', 'bash', 'bats'},
+    'beancount': {'text', 'beancount'},
     'bib': {'text', 'bib'},
     'bmp': {'binary', 'image', 'bitmap'},
     'bz2': {'binary', 'bzip2'},
@@ -171,6 +172,7 @@ EXTENSIONS = {
     'pm': {'text', 'perl'},
     'png': {'binary', 'image', 'png'},
     'po': {'text', 'pofile'},
+    'pom': {'pom', 'text', 'xml'},
     'pp': {'text', 'puppet'},
     'prisma': {'text', 'prisma'},
     'properties': {'text', 'java-properties'},
@@ -222,6 +224,7 @@ EXTENSIONS = {
     'tac': {'text', 'twisted', 'python'},
     'tar': {'binary', 'tar'},
     'tex': {'text', 'tex'},
+    'textproto': {'text', 'textproto'},
     'tf': {'text', 'terraform'},
     'tfvars': {'text', 'terraform'},
     'tgz': {'binary', 'gzip'},
@@ -323,6 +326,7 @@ NAMES = {
     'BUILD.bazel': EXTENSIONS['bzl'],
     'CMakeLists.txt': EXTENSIONS['cmake'],
     'CHANGELOG': EXTENSIONS['txt'],
+    'config.ru': EXTENSIONS['rb'],
     'CONTRIBUTING': EXTENSIONS['txt'],
     'COPYING': EXTENSIONS['txt'],
     'Dockerfile': {'text', 'dockerfile'},
@@ -345,6 +349,7 @@ NAMES = {
     'Pipfile.lock': EXTENSIONS['json'],
     'PKGBUILD': {'text', 'bash', 'pkgbuild', 'alpm'},
     'poetry.lock': EXTENSIONS['toml'],
+    'pom.xml': EXTENSIONS['pom'],
     'pylintrc': EXTENSIONS['ini'] | {'pylintrc'},
     'README': EXTENSIONS['txt'],
     'Rakefile': EXTENSIONS['rb'],
